@@ -1,7 +1,7 @@
 from astrape.utilities.dataloader_lightning import DataModule
 from astrape.utilities.utils_lightning import initialize_datamodule, initialize_model
 from astrape.utilities.utils_lightning import set_default_parameters
-from astrape.utilities.utils import rearrange_dims, SegCELossMetrics, CELossMetrics, BCELossMetrics
+from astrape.utilities.utils import rearrange_dims, SegCELossMetrics, conv_dim, CELossMetrics, BCELossMetrics
 __all__ = [
     "DataModule", 
     "initialize_datamodule", 
@@ -10,5 +10,6 @@ __all__ = [
     "rearrange_dims",
     "SegCELossMetrics",
     "CELossMetrics",
-    "BCELossMetrics"
+    "BCELossMetrics",
+    "conv_dim"
     ]
